@@ -109,8 +109,8 @@ int main (int argc, char *argv[])
     srand (time(NULL));
 
     gnome_program_init (APPID, APPVERSION, LIBGNOMEUI_MODULE,
-	                      argc, argv, GNOME_PARAM_POPT_TABLE, options,
-				                GNOME_PARAM_NONE);
+                        argc, argv, GNOME_PARAM_POPT_TABLE, options,
+                        GNOME_PARAM_NONE);
 
     textbox_setup (); /* needs to be done before text boxes are created */
     
@@ -178,12 +178,36 @@ int main (int argc, char *argv[])
                              (GConfClientNotifyFunc) keys_drop_changed, NULL,
 			     NULL, NULL);
 
-    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/discard",
-                             (GConfClientNotifyFunc) keys_discard_changed,
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/message",
+			     (GConfClientNotifyFunc) keys_message_changed,
 			     NULL, NULL, NULL);
 
-    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/message",
-                             (GConfClientNotifyFunc) keys_message_changed,
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/discard",
+			     (GConfClientNotifyFunc) keys_discard_changed,
+			     NULL, NULL, NULL);
+
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/special1",
+                             (GConfClientNotifyFunc) keys_special1_changed,
+			     NULL, NULL, NULL);
+
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/special2",
+                             (GConfClientNotifyFunc) keys_special2_changed,
+			     NULL, NULL, NULL);
+
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/special3",
+                             (GConfClientNotifyFunc) keys_special3_changed,
+			     NULL, NULL, NULL);
+
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/special4",
+                             (GConfClientNotifyFunc) keys_special4_changed,
+			     NULL, NULL, NULL);
+
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/special5",
+                             (GConfClientNotifyFunc) keys_special5_changed,
+			     NULL, NULL, NULL);
+
+    gconf_client_notify_add (gconf_client, "/apps/gtetrinet/keys/special6",
+                             (GConfClientNotifyFunc) keys_special6_changed,
 			     NULL, NULL, NULL);
 
     gconf_client_notify_add (gconf_client, "/apps/gtetrinet/partyline/enable_timestamps",
@@ -405,8 +429,11 @@ gint keypress (GtkWidget *widget, GdkEventKey *key)
       g_signal_stop_emission_by_name (G_OBJECT(widget), "key-press-event");
       return TRUE;
     }
+
+    if ((key->state & (GDK_MOD1_MASK | GDK_CONTROL_MASK | GDK_SHIFT_MASK)) > 0)
+      return FALSE;
     
-    if (game_area && (gdk_keyval_to_lower (key->keyval) == keys[K_GAMEMSG]))
+    if (game_area && ingame && (gdk_keyval_to_lower (key->keyval) == keys[K_GAMEMSG]))
     {
       g_signal_handler_block (app, keypress_signal);
       fields_gmsginputactivate (TRUE);
@@ -458,18 +485,18 @@ gint keyrelease (GtkWidget *widget, GdkEventKey *key)
  */
 static int gtetrinet_key (int keyval, int mod)
 {
-    if (mod != GDK_MOD1_MASK)
-      return (FALSE);
+  if (mod != GDK_MOD1_MASK)
+    return FALSE;
     
-    switch (keyval)
-    {
-    case GDK_1: gtk_notebook_set_current_page (GTK_NOTEBOOK(notebook), 0); break;
-    case GDK_2: gtk_notebook_set_current_page (GTK_NOTEBOOK(notebook), 1); break;
-    case GDK_3: gtk_notebook_set_current_page (GTK_NOTEBOOK(notebook), 2); break;
-    default:
-        return FALSE;
-    }
-    return TRUE;
+  switch (keyval)
+  {
+  case GDK_1: gtk_notebook_set_current_page (GTK_NOTEBOOK(notebook), 0); break;
+  case GDK_2: gtk_notebook_set_current_page (GTK_NOTEBOOK(notebook), 1); break;
+  case GDK_3: gtk_notebook_set_current_page (GTK_NOTEBOOK(notebook), 2); break;
+  default:
+    return FALSE;
+  }
+  return TRUE;
 }
 
 /* funky page detach stuff */
